@@ -9,7 +9,7 @@
 #' expected value and the core of \code{value}, \code{TriangularSupportDist}--constructs the
 #' triangular fuzzy number based on minimization of \code{DpqDistance}, preserving the support of \code{value},
 #' and the approximation methods from the FuzzyNumbers package (namely: \code{Naive, NearestEuclidean, ExpectedIntervalPreserving,
-#' SupportCoreRestricted}).
+#' SupportCoreRestricted,SupportCorePreserving}).
 #' 
 #'  
 #' 
@@ -30,6 +30,9 @@
 #'
 #'
 #' @param method The selected approximation method.
+#'
+#' @param piecewise If \code{piecewise=TRUE} is set, then the methods "Naive","NearestEuclidean" (from the FuzzyNumbers package) produce piecewise linear fuzzy number as the
+#'  output, otherwise they result in trapezoidal fuzzy number.
 #' 
 #' @param ... Additional parameters passed to other functions (like approximation method from the FuzzyNumbers package).
 #' 
@@ -56,7 +59,7 @@
 #' @export
 
 
-FuzzyApproximation <- function(value,method="ExpectedValueCore",...)
+FuzzyApproximation <- function(value,method="ExpectedValueCore",piecewise=FALSE,...)
 {
   # checking parameters
   
@@ -66,6 +69,11 @@ FuzzyApproximation <- function(value,method="ExpectedValueCore",...)
     
   }
   
+  if(length(method) != 1)
+  {
+    stop("Parameter method should be a single value!")
+  }
+  
   if(!(method %in% c(approximationMehodsInside,approximationMehodsOutside)))
   {
     stop("Parameter method should be a proper name of approximation method!")
@@ -73,6 +81,14 @@ FuzzyApproximation <- function(value,method="ExpectedValueCore",...)
   
   
   
+  if((length(piecewise) != 1) || (!is.logical(piecewise)))
+  {
+    
+    stop("Parameter piecewise should be a single logical value!")
+    
+  }
+  
+  
   if(method=="ExpectedValueCore") {
     
     # apply the Expected-Value and Core Preserving Method
@@ -112,11 +128,39 @@ FuzzyApproximation <- function(value,method="ExpectedValueCore",...)
     
   }
   
-  # use approximation methods from FuzzyNumbers package
+  # apply the approximation with preserving the ambiguity and value
   
-  if(method %in% approximationMehodsOutside) {
+  if(method == "AmbiguityValuePreserving") {
+    
+    output <- ApproximationAmbValPres(value,...)
+    
+  }
+  
+  # use various approximation methods from FuzzyNumbers package regarding the method and piecewise parameter
+  
+  if(method %in% c("SupportCoreRestricted","ExpectedIntervalPreserving")) {
+    
+    output <- FuzzyNumbers::trapezoidalApproximation(value, method=method,...)
+    
+  }
+  
+  if((method %in% c("Naive","NearestEuclidean")) && piecewise==FALSE) {
+    
+    output <- FuzzyNumbers::trapezoidalApproximation(value, method=method,...)
+    
+  }
+  
+  
+  
+  if((method %in% c("Naive","NearestEuclidean")) && piecewise==TRUE) {
  
-    output <- FuzzyNumbers::piecewiseLinearApproximation(value, method=method)
+    output <- FuzzyNumbers::piecewiseLinearApproximation(value, method=method,...)
+    
+  }
+  
+  if(method=="SupportCorePreserving") {
+    
+    output <- FuzzyNumbers::piecewiseLinearApproximation(value, method=method,...)
     
   }
   
